==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/b1/b1c85a55ac1c1630ac4d31a95095c62d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Exception/MailboxException.php */
class __TwigTemplate_830abbaa11172e18cfb522746c5c7c7c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Exception;

class MailboxException extends \\Exception
{
    public function __construct(\$message = null, \$code = 0, \\Exception \$previous = null)
    {
        if (null === \$message) {
            \$message = 'Error communicating with the IMAP server';

            if (function_exists('imap_last_error')) {
                \$message .= ': '.imap_last_error();
            }
        }

        parent::__construct(\$message, \$code, \$previous);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Exception/MailboxException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Exception/MailboxException.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Exception/MailboxException.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/b1/b1c85a55ac1c1630ac4d31a95095c62d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Exception/MailboxException.php */
class __TwigTemplate_830abbaa11172e18cfb522746c5c7c7c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Exception;

class MailboxException extends \\Exception
{
    public function __construct(\$message = null, \$code = 0, \\Exception \$previous = null)
    {
        if (null === \$message) {
            \$message = 'Error communicating with the IMAP server';

            if (function_exists('imap_last_error')) {
                \$message .= ': '.imap_last_error();
            }
        }

        parent::__construct(\$message, \$code, \$previous);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Exception/MailboxException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Exception/MailboxException.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Exception/MailboxException.php");
    }
}
